# Hydraflow Documentation

Hydraflow integrates [Hydra](https://hydra.cc/) and [MLflow](https://mlflow.org/)
to manage and track machine learning experiments.

## Installation

```bash
pip install hydraflow
```